#
# This file is part of App-Module-Locate
#
# This software is copyright (c) 2011 by celogeek <me@celogeek.com>.
#
# This is free software; you can redistribute it and/or modify it under
# the same terms as the Perl 5 programming language system itself.
#
package App::Module::Locate;

# ABSTRACT: Interface for module locate
use strict;
use warnings;
our $VERSION = '0.3';    # VERSION
1;

__END__

=pod

=head1 NAME

App::Module::Locate - Interface for module locate

=head1 VERSION

version 0.3

=head1 AUTHOR

celogeek <me@celogeek.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by celogeek <me@celogeek.com>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
